@@ -53,7 +53,7 @@ TMDB_API_KEY = os.getenv("VROBBLER_TMDB_API_KEY", "")
 
 DEFAULT_AUTO_FIELD = 'django.db.models.BigAutoField'
 
-TIME_ZONE = os.getenv("VROBBLER_TIME_ZONE", "EST")
+TIME_ZONE = os.getenv("VROBBLER_TIME_ZONE", "US/Eastern")
 
 ALLOWED_HOSTS = ["*"]
 CSRF_TRUSTED_ORIGINS = [
@@ -61,14 +61,9 @@ CSRF_TRUSTED_ORIGINS = [
 ]
 X_FRAME_OPTIONS = "SAMEORIGIN"
 
+CACHALOT_TIMEOUT = os.getenv("VROBBLER_CACHALOT_TIMEOUT", 3600)
 REDIS_URL = os.getenv("VROBBLER_REDIS_URL", None)
 
-CELERY_TASK_ALWAYS_EAGER = os.getenv("VROBBLER_SKIP_CELERY", False)
-CELERY_BROKER_URL = REDIS_URL if REDIS_URL else "memory://localhost/"
-CELERY_RESULT_BACKEND = "django-db"
-CELERY_TIMEZONE = os.getenv("VROBBLER_TIME_ZONE", "EST")
-CELERY_TASK_TRACK_STARTED = True
-
 INSTALLED_APPS = [
     "django.contrib.admin",
     "django.contrib.auth",
@@ -81,6 +76,8 @@ INSTALLED_APPS = [
     "django_filters",
     "django_extensions",
     'rest_framework.authtoken',
+    "cachalot",
+    "profiles",
     "scrobbles",
     "videos",
     "music",
@@ -163,8 +160,8 @@ AUTHENTICATION_BACKENDS = [
 REST_FRAMEWORK = {
     "DEFAULT_PERMISSION_CLASSES": ("rest_framework.permissions.AllowAny",),
     'DEFAULT_AUTHENTICATION_CLASSES': [
-        #'rest_framework.authentication.BasicAuthentication',
-        #'rest_framework.authentication.TokenAuthentication',
+        'rest_framework.authentication.BasicAuthentication',
+        'rest_framework.authentication.TokenAuthentication',
         'rest_framework.authentication.SessionAuthentication',
     ],
     "DEFAULT_PAGINATION_CLASS": "rest_framework.pagination.PageNumberPagination",
@@ -205,8 +202,6 @@ TIME_ZONE = os.getenv("VROBBLER_TIME_ZONE", "EST")
 
 USE_I18N = True
 
-USE_L10N = True
-
 USE_TZ = True
 
 
@@ -217,10 +212,6 @@ STATIC_URL = "static/"
 STATIC_ROOT = os.getenv(
     "VROBBLER_STATIC_ROOT", os.path.join(PROJECT_ROOT, "static")
 )
-if not DEBUG:
-    STATICFILES_STORAGE = (
-        "whitenoise.storage.CompressedManifestStaticFilesStorage"
-    )
 
 MEDIA_URL = "/media/"
 MEDIA_ROOT = os.getenv(
